/* lirc_it87.h */
/* SECTION: Definitions */

/********************************* ITE it87 ************************/

/* it87 Ports: */
#define it87_ADRPORT      	0x4e
#define it87_DATAPORT     	0x4f

/* it87 Registers */
#define it87_LDN          	0x7
#define it87_CHIP_ID1     	0x20
#define it87_CHIP_ID2     	0x21


#define it8712_CIR_LDN    		0xa
#define it8713_CIR_LDN    		0xa
#define IT8752_CIR_LDN    		0xa

/* CIR Configuration Registers: */
#define it87_CIR_ACT      	0x30
#define it87_CIR_BASE_MSB 	0x60
#define it87_CIR_BASE_LSB 	0x61
#define it87_CIR_IRQ      	0x70
#define it87_CIR_IRQTP	  	0x71

/* List of it87_CIR registers: offset to BaseAddr */

#define it87_CIR_C0DR				0
#define it87_CIR_C0MSTCR		1
#define it87_CIR_C0IER			2
#define it87_CIR_C0IIR			3
#define it87_CIR_C0CFR			4
#define it87_CIR_C0RCR			5
#define it87_CIR_C0TCR			7
#define it87_CIR_C0SCK			3
#define it87_CIR_C0WCSSR		0
#define it87_CIR_C0BDLR			1
#define it87_CIR_C0BDHR			2
#define it87_CIR_C0TFSR			6
#define it87_CIR_C0RFSR			4
#define it87_CIR_C0WCL			5
#define it87_CIR_C0WCR			6
#define it87_CIR_C0WPS			7
#define it87_CIR_CSCRR			0
#define it87_CIR_CGPINTR		1

/* Bit Definitionen */

/* C0MSTCR */
#define	it87_CIR_C0MSTCR_RESEVED			0xc0
#define	it87_CIR_C0MSTCR_ILSEL				0x20
#define	it87_CIR_C0MSTCR_ILE				0x10
#define	it87_CIR_C0MSTCR_FIFOTL				0xc
#define	it87_CIR_C0MSTCR_FIFOCLR			0x2
#define	it87_CIR_C0MSTCR_RESET				0x1

/* C0IER */
#define it87_CIR_C0IER_IEC     				0x80
#define it87_CIR_C0IER_WCIT	   				0x40
#define it87_CIR_C0IER_RESEVED 				0x28
#define it87_CIR_C0IER_RFOIE   				0x4
#define it87_CIR_C0IER_RDAIE   				0x2
#define it87_CIR_C0IER_TLDLIE  				0x1

/* C0IIR */
#define it87_CIR_C0IIR_NIP 					0x80
#define it87_CIR_C0IIR_RESERVED 			0x78
#define it87_CIR_C0IIR_RFOI 				0x4
#define it87_CIR_C0IIR_RDAI     			0x2
#define it87_CIR_C0IIR_TLDLI    			0x1

/* C0CFR */
#define it87_CIR_C0CFR_RESEVED				0xc0
#define it87_CIR_C0CFR_HCFS   				0x20
#define it87_CIR_C0CFR_CFQ 					0x1f

/* C0RCR */
#define it87_CIR_C0RCR_RXEN   				0x80
#define it87_CIR_C0RCR_RESEVED				0x40
#define it87_CIR_C0RCR_RDWOS  				0x20
#define it87_CIR_C0RCR_RXEND  				0x10
#define it87_CIR_C0RCR_RXACT  				0x8
#define it87_CIR_C0RCR_RXDCR  				0x7

/* C0TCR */
#define it87_CIR_C0TCR1_RESEVED				0x80
#define it87_CIR_C0TCR1_TXRLE				0x40
#define it87_CIR_C0TCR1_TXENDF				0x20
#define it87_CIR_C0TCR1_TXMPM				0x18
#define it87_CIR_C0TCR1_TXMPW				0x7

/* C0SCK */
#define it87_CIR_C0SCK_DLLOCK				0x80
#define it87_CIR_C0SCK_BRCM					0x70
#define it87_CIR_C0SCK_DLLTE				0x8
#define it87_CIR_C0SCK_DLL1P8E				0x4
#define it87_CIR_C0SCK_TXDCKG				0x2
#define it87_CIR_C0SCK_SCKS					0x1

/* C0TFSR */
#define it87_CIR_C0TFSR_RESERVED 			0xc0
#define it87_CIR_C0TFSR_TXFBC    			0x3f

/* C0RFSR */
#define it87_CIR_C0RFSR_RXFTO    			0x80
#define it87_CIR_C0RFSR_RESERVED 			0x40
#define it87_CIR_C0RFSR_RXFBC    			0x3f

/* C0WCSSR */
#define it87_CIR_C0WCSSR_WUCSI				0xe0
#define it87_CIR_C0WCSSR_RESERVED			0x1f

/* C0WCL */
#define it87_CIR_C0WCL_RESERVED				0xc0
#define it87_CIR_C0WCL_WCL					0x3f

/* C0WPS */
#define it87_CIR_C0WPS_RESERVED1			0xc0
#define it87_CIR_C0WPS_WCRST				0x20
#define it87_CIR_C0WPS_RCRST				0x10
#define it87_CIR_C0WPS_RESERVED2			0x8
#define it87_CIR_C0WPS_CIRPOII				0x4
#define it87_CIR_C0WPS_CIRPOIS				0x2
#define it87_CIR_C0WPS_CIRPOSIE				0x1

/* CSCRR */
#define it87_CIR_CSCRR_PM					0x80
#define it87_CIR_CSCRR_RESERVED				0x40
#define it87_CIR_CSCRR_SCRB					0x3f

/* CGPINTR */
#define it87_CIR_CGPINTR_RESERVED			0xfe
#define it87_CIR_CGPINTR_CGPINT				0x1


#define it87_CIR_FIFO_SIZE 32

/* Baudratedivisor for IT87: power of 2: only 1,2,4 or 8) */
#define it87_CIR_BAUDRATE_DIVISOR			0x1
#define it87_CIR_DEFAULT_IOBASE				0x310
#define it87_CIR_DEFAULT_IRQ				0x7
#define it87_CIR_SPACE					0x00
#define it87_CIR_PULSE					0xff
#define it87_CIR_FREQ_MIN				27
#define it87_CIR_FREQ_MAX				58
#define TIME_CONST (it87_CIR_BAUDRATE_DIVISOR * 8000000ul / 115200ul)

/********************************* ITE IT87xx ************************/
